@@ -3,7 +3,7 @@ package Net::Async::Trello::WS;
 use strict;
 use warnings;
 
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use parent qw(IO::Async::Notifier);
 
@@ -27,21 +27,21 @@ sub configure {
 sub connection {
     my ($self, %args) = @_;
     $self->{ws_connection} ||= do {
+        $log->tracef('Set up WS connection');
         my $uri = $self->trello->endpoint(
             'websockets',
             token => $self->token,
         );
+        $log->tracef('Connecting to websocket endpoint %s', "$uri");
         $self->{ws}->connect(
             url        => $uri,
             host       => $uri->host,
-            ($uri->scheme eq 'wss'
-            ? (
-                service      => 443,
-                extensions   => [ qw(SSL) ],
-                SSL_hostname => $uri->host,
-            ) : (
-                service    => 80,
-            ))
+            (
+                $uri->scheme eq 'wss'
+                ? (
+                    SSL_hostname => $uri->host,
+                ) : ()
+            )
         )->then(sub {
             my ($conn) = @_;
             $log->tracef("Connected");
@@ -56,29 +56,38 @@ my %model_for_type = (
     card => 'Card'
 );
 
+sub next_request_id {
+    return (shift->{last_request_id} //= 0)++;
+}
+
 sub subscribe {
     my ($self, $type, $id) = @_;
     $self->connection->then(sub {
         my ($conn) = @_;
         $log->tracef("Subscribing to %s %s", $type, $id);
+        my $src = $self->{update_channel}{$id} //= $self->ryu->source;
         $conn->send_frame(
             buffer => $json->encode({
                 idModel          => $id,
                 invitationTokens => [],
                 modelType        => $model_for_type{$type},
-                reqid            => 1,
+                reqid            => $self->next_request_id,
                 tags             => [qw(clientActions updates)],
                 type             => "subscribe",
             }),
             masked => 1
         );
+        return Future->done($src);
     })
 }
 
+sub websocket_events { my ($self) = @_; $self->{websocket_events} //= $self->ryu->source }
+
 sub on_frame {
 	my ($self, $ws, $bytes) = @_;
-    my $text = Encode::decode_utf8($bytes);
+    my $text = $bytes; # Encode::decode_utf8($bytes);
     $log->debugf("Have frame [%s]", $text);
+    $self->websocket_events->emit($text);
 
     if(length $text) {
         $log->tracef("<< %s", $text);
@@ -94,6 +103,7 @@ sub on_frame {
             $log->errorf("Exception in websocket raw frame handling: %s (original text %s)", $@, $text);
         }
     } else {
+        $log->tracef("<< ping received, responding");
         # Empty frame is used for PING, send a response back
         $self->pong;
     }
@@ -101,11 +111,10 @@ sub on_frame {
 
 sub pong {
     my ($self) = @_;
-    $self->{ws}->send_frame('');
-}
-
-sub next_request_id {
-    ++shift->{request_id}
+    $self->{ws}->send_frame(
+        masked => 1,
+        buffer => ''
+    );
 }
 
 sub _add_to_loop {
@@ -120,14 +129,16 @@ sub _add_to_loop {
             on_frame => $self->curry::weak::on_frame,
         )
     );
-    $self->add_child(
-        my $timer = IO::Async::Timer::Periodic->new(
-            interval => 15,
-            on_tick => $self->curry::weak::on_tick,
-        )
-    );
-    $timer->start;
-    Scalar::Util::weaken($self->{timer} = $timer);
+    if(0) {
+        $self->add_child(
+            my $timer = IO::Async::Timer::Periodic->new(
+                interval => 15,
+                on_tick => $self->curry::weak::on_tick,
+            )
+        );
+        $timer->start;
+        Scalar::Util::weaken($self->{timer} = $timer);
+    }
 }
 
 sub on_tick {
